/*
 * Examples of usage:
 * https://home.et.utwente.nl/slootenvanf/2019/11/15/using-oled-display-with-arduino/
 * https://home.et.utwente.nl/slootenvanf/2019/04/04/displays/
 * 
 * You must install the u8g2 library before you use this sketch:
 * Select Tools > Manage Libraries, then search for "U8g2" and install the library.
 * 
 * Learn more about the use of library U8g2:
 * https://github.com/olikraus/u8g2/wiki/u8x8reference
 * This example is based on the original "hello world" example which comes with the library
 * (File > Examples > U8g2 > u8x8 > HelloWorld)
 * 
 * This sketch be used in combination with the EVShield too (in hardware i2c mode).
 * 
 * Connections (hardware i2c):
 * Display: Arduino:
 * GND      GND
 * VCC      VCC (3.3 or 5V)
 * SDA      SDA (pin A4)
 * SCL      SCL (pin A5)
 */
#include <U8g2lib.h>

// software i2c:
//U8X8_SSD1306_128X64_NONAME_SW_I2C u8x8(7, 8, U8X8_PIN_NONE);
// hardware i2c:
U8X8_SSD1306_128X64_NONAME_HW_I2C display(U8X8_PIN_NONE);

char buf[10]; // text buffer; to be able to use draw2x2String to show the value
int speed = 30; // count down speed

void setup() {
  display.begin();
  display.setPowerSave(0);

  display.setFont(u8x8_font_pxplusibmcgathin_f);
  display.drawString(0,0,"Hello World v1!");
  //display.drawString(0,6,"1234567890123456");
  display.drawString(0,7,"Hello World 2019");
}

void loop() {
  if (speed<0) return; // do nothing if speed is smaller than zero
  
  // displaying variable speed in a large (2x2) font:
  snprintf(buf, 10, "%2d", speed--); // count down speed; %2d means we have two decimal places (because our value is always between 0 - 30)
  display.draw2x2String(0,1,"Speed: ");
  display.draw2x2String(0,4,buf);
  // alternative: display using print (simpler, no text buffer needed, but cannot use large 2x2 font)
  //display.setCursor(7, 1);
  //display.print(speed);
  delay(1000); // wait one second
}
